"use strict";
const express = require("express");
const util = require("util");
const glob = require("glob");
const fs = require("fs");
const readFile = util.promisify(fs.readFile);
const readdir = util.promisify(fs.readdir);
const globPromise = util.promisify(glob);

const app = express();
app.use(express.static("public/"));
const SERVER_ERROR_MSG = "Something went wrong on the server, please try again later.";

app.get("/meal/:type", async (req, res) => {
  let type = req.params.type;
  res.type("text");
  try {
    let txts = await globPromise("data/" + type.toLowerCase() + "/*txt");
    if (txts.length === 0) {
      res.status(400).send(type + " not a valid meal type.");
    } else {
      let results = "";
      for (let i = 0; i < txts.length; i++) {
        let contents = await readFile(txts[i], "utf8");
        let lines = contents.split("\n");
        results += lines[0] + ": " + lines[1] + "\n";
      }
      res.send(results);
    }
  } catch (err) {
    res.status(500).send(SERVER_ERROR_MSG);
  }
});

app.get("/dayplan", async (req, res) => {
  try {
    let randBreakfast = await getRandOption("breakfast");
    let randLunch = await getRandOption("lunch");
    let randDinner = await getRandOption("dinner");
    let results = {
      "breakfast" : randBreakfast,
      "lunch" : randLunch,
      "dinner" : randDinner
    };
    res.json(results);
  } catch (err) {
    res.status(500).send(SERVER_ERROR_MSG);
  }
});

async function getRandOption(mealType) {
  let txts = await globPromise("data/" + mealType + "/*txt");
  let randOption = txts[Math.floor(Math.random() * txts.length)];
  let contents = await readFile(randOption, "utf8");
  let lines = contents.split("\n");
  return {
    "name" : lines[0], "description" : lines[1], "food-groups" : lines[2].split(" ")
  };
}

const PORT = process.env.PORT || 8000;
app.listen(PORT);
